﻿using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media.Animation;

namespace de.mhoapps.DropToZip.View
{
    /// <summary>
    /// Helfer für Animation von Seiten auf bestimmte Weise
    /// </ summary>
    public static class PageAnimations
    {
        /// <summary>
        /// Schiebt eine Seite von rechts hinein
        /// </ summary>
        /// <param name = "page"> Die zu animierende Seite </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <returns> </ returns>
        public static async Task SlideAndFadeInFromRightAsync(this Page page, float seconds)
        {
            var sb = new Storyboard();
            sb.AddSlideFromRight(seconds, page.WindowWidth);
            sb.AddFadeIn(seconds);
            sb.Begin(page);
            page.Visibility = Visibility.Visible;
            await Task.Delay((int)(seconds * 1000));
        }

        /// <summary>
        /// Schiebt eine Seite nach links raus
        /// </ summary>
        /// <param name = "page"> Die zu animierende Seite </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <returns> </ returns>
        public static async Task SlideAndFadeOutToLeftAsync(this Page page, float seconds)
        {
            var sb = new Storyboard();
            sb.AddSlideToLeft(seconds, page.WindowWidth);
            sb.AddFadeOut(seconds);
            sb.Begin(page);
            page.Visibility = Visibility.Visible;
            await Task.Delay((int)(seconds * 1000));
        }
    }
    // <summary>
    /// Stile der Seitenanimation zum Ein- / Ausblenden
    /// </ summary>
    public enum PageAnimationEnum
    {
        None = 0,
        SlideAndFadeInFromRight = 1,
        SlideAndFadeOutToLeft = 2,
    }
}
