﻿using System;
using System.Windows;
using System.Windows.Media.Animation;

namespace de.mhoapps.DropToZip.View
{
    /// <summary>
    /// Animationshilfen für<see cref="Storyboard"/>
    /// </ summary>
    public static class StoryboardHelper
    {
        #region Sliding To/From Left

        /// <summary>
        /// Fügt dem Storyboard eine von links schieben Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation</ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <param name = "offset"> Der Abstand nach links, ab dem begonnen werden soll </param>
        /// <param name = "decelerationRatio"> Die Verzögerungsrate </ param>
        /// <param name = "keepMargin"> Gibt an, ob das Element während der Animation die gleiche Breite haben soll. </ param>
        public static void AddSlideFromLeft(this Storyboard storyboard, float seconds, double offset, float decelerationRatio = 0.9f, bool keepMargin = true)
        {
            var animation = new ThicknessAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = new Thickness(-offset, 0, keepMargin ? offset : 0, 0),
                To = new Thickness(0),
                DecelerationRatio = decelerationRatio
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Margin"));
            storyboard.Children.Add(animation);
        }

        /// <summary>
        /// Fügt dem Storyboard eine nach links schieben Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <param name = "offset"> Der Abstand nach links zum Ende </ param>
        /// <param name = "decelerationRatio"> Die Verzögerungsrate </ param>
        /// <param name = "keepMargin"> Gibt an, ob das Element während der Animation die gleiche Breite haben soll. </ param>
        public static void AddSlideToLeft(this Storyboard storyboard, float seconds, double offset, float decelerationRatio = 0.9f, bool keepMargin = true)
        {
            var animation = new ThicknessAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = new Thickness(0),
                To = new Thickness(-offset, 0, keepMargin ? offset : 0, 0),
                DecelerationRatio = decelerationRatio
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Margin"));
            storyboard.Children.Add(animation);
        }

        #endregion

        #region Sliding To/From Right

        /// <summary>
        /// Fügt dem Storyboard eine von rechts schieben Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <param name = "offset"> Der Abstand nach rechts, ab dem  begonnen werden soll</ param>
        /// <param name = "decelerationRatio"> Die Verzögerungsrate </ param>
        /// <param name = "keepMargin"> Gibt an, ob das Element während der Animation die gleiche Breite haben soll. </ param>
        public static void AddSlideFromRight(this Storyboard storyboard, float seconds, double offset, float decelerationRatio = 0.9f, bool keepMargin = true)
        {
            var animation = new ThicknessAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = new Thickness(keepMargin ? offset : 0, 0, -offset, 0),
                To = new Thickness(0),
                DecelerationRatio = decelerationRatio
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Margin"));
            storyboard.Children.Add(animation);
        }

        /// <summary>
        /// Fügt dem Storyboard eine nach rechts schieben Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation zu </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <param name = "offset"> Der Abstand nach rechts bis zum Ende </ param>
        /// <param name = "decelerationRatio"> Die Verzögerungsrate </ param>
        /// <param name = "keepMargin"> Gibt an, ob das Element während der Animation die gleiche Breite haben soll. </ param>
        public static void AddSlideToRight(this Storyboard storyboard, float seconds, double offset, float decelerationRatio = 0.9f, bool keepMargin = true)
        {
            var animation = new ThicknessAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = new Thickness(0),
                To = new Thickness(keepMargin ? offset : 0, 0, -offset, 0),
                DecelerationRatio = decelerationRatio
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Margin"));
            storyboard.Children.Add(animation);
        }

        #endregion

        #region Sliding To/From Top

        /// <summary>
        /// Fügt dem Storyboard eine von oben schieben Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <param name = "offset"> Der Abstand zum Anfang, ab dem begonnen werden soll</ param> 
        /// <param name = "decelerationRatio"> Die Verzögerungsrate </ param>
        /// <param name = "keepMargin"> Gibt an, ob das Element während der Animation auf derselben Höhe gehalten werden soll </ param>
        public static void AddSlideFromTop(this Storyboard storyboard, float seconds, double offset, float decelerationRatio = 0.9f, bool keepMargin = true)
        {
            var animation = new ThicknessAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = new Thickness(0, -offset, 0, keepMargin ? offset : 0),
                To = new Thickness(0),
                DecelerationRatio = decelerationRatio
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Margin"));
            storyboard.Children.Add(animation);
        }

        /// <summary>
        /// Fügt dem Storyboard eine nach oben schieben Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <param name = "offset"> Der Abstand zum oberen Ende </ param>
        /// <param name = "decelerationRatio"> Die Verzögerungsrate </ param>
        /// <param name = "keepMargin"> Gibt an, ob das Element während der Animation auf derselben Höhe gehalten werden soll </ param>
        public static void AddSlideToTop(this Storyboard storyboard, float seconds, double offset, float decelerationRatio = 0.9f, bool keepMargin = true)
        {
            var animation = new ThicknessAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = new Thickness(0),
                To = new Thickness(0, -offset, 0, keepMargin ? offset : 0),
                DecelerationRatio = decelerationRatio
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Margin"));
            storyboard.Children.Add(animation);
        }

        #endregion

        #region Sliding To/From Bottom

        /// <summary>
        /// Fügt dem Storyboard eine von unten schieben Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation zu </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <param name = "offset"> Der Abstand zum Boden, ab dem  begonnen werden soll</ param>
        /// <param name = "decelerationRatio"> Die Verzögerungsrate </ param>
        /// <param name = "keepMargin"> Gibt an, ob das Element während der Animation auf derselben Höhe gehalten werden soll </ param>
        public static void AddSlideFromBottom(this Storyboard storyboard, float seconds, double offset, float decelerationRatio = 0.9f, bool keepMargin = true)
        {
            var animation = new ThicknessAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = new Thickness(0, keepMargin ? offset : 0, 0, -offset),
                To = new Thickness(0),
                DecelerationRatio = decelerationRatio
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Margin"));
            storyboard.Children.Add(animation);
        }

        /// <summary>
        /// Fügt dem Storyboard eine nach unten schieben Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        /// <param name = "offset"> Der Abstand zum unteren Ende </ param>
        /// <param name = "decelerationRatio"> Die Verzögerungsrate </ param>
        /// <param name = "keepMargin"> Gibt an, ob das Element während der Animation auf derselben Höhe gehalten werden soll </ param>
        public static void AddSlideToBottom(this Storyboard storyboard, float seconds, double offset, float decelerationRatio = 0.9f, bool keepMargin = true)
        {
            var animation = new ThicknessAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = new Thickness(0),
                To = new Thickness(0, keepMargin ? offset : 0, 0, -offset),
                DecelerationRatio = decelerationRatio
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Margin"));
            storyboard.Children.Add(animation);
        }

        #endregion

        #region Fade In/Out

        /// <summary>
        /// Fügt dem Storyboard eine einblenden Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        public static void AddFadeIn(this Storyboard storyboard, float seconds)
        {
            var animation = new DoubleAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = 0,
                To = 1,
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Opacity"));
            storyboard.Children.Add(animation);
        }

        /// <summary>
        /// Fügt dem Storyboard eine ausblenden Animation hinzu
        /// </ summary>
        /// <param name = "storyboard"> Das Storyboard zum Hinzufügen der Animation </ param>
        /// <param name = "seconds"> Die Zeit, die die Animation benötigt </ param>
        public static void AddFadeOut(this Storyboard storyboard, float seconds)
        {
            var animation = new DoubleAnimation
            {
                Duration = new Duration(TimeSpan.FromSeconds(seconds)),
                From = 1,
                To = 0,
            };
            Storyboard.SetTargetProperty(animation, new PropertyPath("Opacity"));
            storyboard.Children.Add(animation);
        }

        #endregion
    }
}
