﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;

namespace de.mhoapps.DropToZip.View
{
    public class TextEntryWidthMatcherProperty : AttachedPropertyBase<TextEntryWidthMatcherProperty, bool>
    {
        public override void OnValueChanged(DependencyObject sender, DependencyPropertyChangedEventArgs e)
        {
            var panel = (sender as Panel);
            SetWidth(panel);
            RoutedEventHandler onloaded = null;
            onloaded = (s, ee) =>
            {
                panel.Loaded -= onloaded;

                SetWidth(panel);

                foreach (var child in panel.Children)
                {

                    if (!(child is ucTextEntry control)) continue;

                    control.Label.SizeChanged += (ss, eee) =>
                    {
                        SetWidth(panel);
                    };
                }
            };
            panel.Loaded += onloaded;
        }

        /// <summary>
        /// aktualisiere alle untergeordneten Texteingabesteuerelemente so, dass ihre Breite mit der größten Breite der Gruppe übereinstimmt
        /// </ summary>
        /// <param name = "panel"> Das Bedienfeld mit den Steuerelementen für die Texteingabe </ param>
        private void SetWidth(Panel panel)
        {
            var maxSize = 0d;

            foreach (var child in panel.Children)
            {

                if (!(child is ucTextEntry) && !(child is ucFolderEntry) ) continue;

                var label = child is ucTextEntry ? (child as ucTextEntry).Label : (child as ucFolderEntry).Label;

                maxSize = Math.Max(maxSize, label.RenderSize.Width + label.Margin.Left + label.Margin.Right);
            }

            var gridLength = (GridLength)new GridLengthConverter().ConvertFromString(maxSize.ToString());

            foreach (var child in panel.Children)
            {
                if (child is ucTextEntry text)
                    text.LabelWidth = gridLength;
                else if (child is ucFolderEntry fold)
                    fold.LabelWidth = gridLength;
            }
        }
    }
}
