﻿using de.mhoapps.DropToZip.ViewModel;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace de.mhoapps.DropToZip.View
{
    public class DialogUserControlBase : UserControl
    {
        #region Private Members

        /// <summary>
        /// Das Dialogfenster, in dem wir uns befinden
        /// </ summary>
        private DialogWindow _dialogWindow;

        #endregion

        #region Public Commands

        /// <summary>
        /// Schließt den Dialog
        /// </summary>
        public ICommand CloseCommand { get; private set; }
        public ICommand CloseAndSaveCommand { get; private set; }

        #endregion

        #region Public Properties

        /// <summary>
        /// die Mindestbreite des Dialog
        /// </summary>
        public int WindowMinimumWidth { get; set; } = 250;

        /// <summary>
        /// die MindestHöhe des Dialog
        /// </summary>
        public int WindowMinimumHeight { get; set; } = 100;

        /// <summary>
        /// die Höhe der Titlebar
        /// </summary>
        public int TitleHeight { get; set; } = 30;

        /// <summary>
        /// der Titel für den Dialog
        /// </summary>
        public string Title { get; set; }

        #endregion

        #region Constructor

        /// <summary>
        /// Default constructor
        /// </summary>
        public DialogUserControlBase()
        {
            if (!DesignerProperties.GetIsInDesignMode(this))
            {
                _dialogWindow = new DialogWindow();
                _dialogWindow.ViewModel = new DialogWindowViewModel(_dialogWindow);
                CloseCommand = new RelayCommand(c => _dialogWindow.Close());
                CloseAndSaveCommand = new RelayCommand(c => CloseAndSave(c));
            }
        }

        #endregion

        #region Command Methods

        private void CloseAndSave(object param)
        {
            if (param != null)
            {
                var path = param as DirectoryItemViewModel;
                IoC.Settings.ZipPath.OriginalText = path.FullPath;
            }
            _dialogWindow.Close();
        }

        #endregion

        #region Public Dialog Show Methods

        /// <summary>
        /// Zeigt dem Benutzer ein einzelnes Dialog Fenster an
        /// </ summary>
        /// <param name = "viewModel"> Das ViewModelm>
        /// <typeparam name = "T"> Der ViewModeltyp für dieses Steuerelement </ typeparam>
        /// <returns> </ returns>
        public Task ShowDialog<T>(T viewModel)
            where T : DialogViewModelBase
        {
            // einen Task erstellen um auf das schließen des Dialog zu warten
            var tcs = new TaskCompletionSource<bool>();

            // im UI Thread laufen lassen
            Application.Current.Dispatcher.Invoke(() =>
            {
                try
                {
                    // Steuert die erwarteten Größen aus dem ViewModel des Dialogfelds
                    _dialogWindow.ViewModel.WindowMinimumWidth = WindowMinimumWidth;
                    _dialogWindow.ViewModel.WindowMinimumHeight = WindowMinimumHeight;
                    _dialogWindow.ViewModel.TitleHeight = TitleHeight;
                    _dialogWindow.ViewModel.Title = string.IsNullOrEmpty(viewModel.Title) ? Title : viewModel.Title;

                    // Setze dieses Steuerelement auf den Inhalt des Dialogfensters
                    _dialogWindow.ViewModel.Content = this;

                    // Datenkontext an das ViewModel binden
                    DataContext = viewModel;

                    // in der Mitte des Hauptfensters anzeigen
                    _dialogWindow.Owner = Application.Current.MainWindow;
                    _dialogWindow.WindowStartupLocation = WindowStartupLocation.CenterOwner;

                    // Dialog anzeigen
                    _dialogWindow.ShowDialog();
                }
                finally
                {
                    // Task bescheid geben das wir fertig sind
                    tcs.TrySetResult(true);
                }
            });
            return tcs.Task;
        }
        #endregion
    }
}
