﻿using System;
using System.Security;

namespace de.mhoapps.DropToZip.ViewModel
{
    /// <summary>
    /// das View Model das die Application abbildet
    /// </summary>
    public class ApplicationViewModel : ViewModelBase
    {

        public ApplicationViewModel()
        {
            SettingsPath = Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData);
        }

        /// <summary>
        /// wahr wenn das Seitenmenü angezeigt werden soll
        /// </summary>
        public bool SideMenuVisible { get; set; }

        /// <summary>
        /// wahr wenn das Settingsmenü gezeigt werden soll
        /// </summary>
        public bool SettingsMenuVisible { get; set; }

        /// <summary>
        /// wahr wenn der About Bildschirm angezeigt werden soll
        /// </summary>
        public bool AboutMenuVisible { get; set; }

        /// <summary>
        /// die aktuelle Seite im Hauptfenster
        /// </summary>
        public PagesEnum CurrentPage { get; set; } = PagesEnum.Main;

        /// <summary>
        /// das aktuelle ViewModel der Seite
        /// </summary>
        public ViewModelBase CurrentViewModel { get; set; }

        /// <summary>
        /// der aktuelle Pfad zum Zip Container
        /// </summary>
        public string ZipPath { get; set; }

        /// <summary>
        /// der aktuelle Name des ZipContainers
        /// </summary>
        public string ZipName { get; set; }

        /// <summary>
        /// der Pfad für die Settings Datei
        /// </summary>
        public string SettingsPath { get; set; }

        /// <summary>
        /// navigiert zur angegbenen Seite
        /// </summary>
        /// <param name="page">die Seite zu der navigiert werden soll</param>
        /// <param name="vieModel">das ViewModel dazu, falls eins benötigt wird</param>
        public void GoToPage(PagesEnum page, ViewModelBase vieModel = null)
        {
            CurrentViewModel = vieModel;
            CurrentPage = page;
            OnPropertyChanged(nameof(CurrentPage));
            SideMenuVisible = page == PagesEnum.Main;
        }
    }
}
