﻿using de.mhoapps.DropToZip.Model;
using System;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Windows.Input;

namespace de.mhoapps.DropToZip.ViewModel
{
    public class DirectoryItemViewModel : ViewModelBase
    {
        #region Constructor

        /// <summary>
        /// default constructor
        /// </summary>
        public DirectoryItemViewModel()
        {

        }

        public DirectoryItemViewModel(string fullPath, DirectoryItemTypeEnum type)
        {
            FullPath = fullPath;
            Type = type;
            ClearDirectoryItems();
            InitCommands();
        }

        #endregion

        #region Public Properties

        #region Model Properties

        public string FullPath { get; set; }

        public string Name => Type == DirectoryItemTypeEnum.Drive ? FullPath : FullPath.GetFileFolderName();

        public DirectoryItemTypeEnum Type { get; set; }

        #endregion

        #region UI Properties

        public string ImageName => Type == DirectoryItemTypeEnum.Drive ? "drive" : (Type == DirectoryItemTypeEnum.File ? "file" : (IsExpanded ? "folder-open" : "folder-close"));

        public ObservableCollection<DirectoryItemViewModel> ChildItems { get; set; }

        public bool CanOpen => Type == DirectoryItemTypeEnum.File;

        public bool CanExpand => Type != DirectoryItemTypeEnum.File;

        public bool IsExpanded
        {
            get => ChildItems?.Count(i => i != null) > 0;
            set
            {
                if (value == true)
                    Expand();
                else
                    ClearDirectoryItems();
            }
        }
        #endregion
        #endregion

        #region Commands

        public ICommand ExpandCommand { get; set; }

        #endregion

        #region Command Methods
        private void Expand()
        {
           
            if (Type == DirectoryItemTypeEnum.File)
                return;
            var childItems = FullPath.GetFolders();
            ChildItems = new ObservableCollection<DirectoryItemViewModel>(childItems.Select(child => new DirectoryItemViewModel(child.FullPath, child.Type)));
        }

        #endregion

        #region Helper Methods

        private void InitCommands()
        {
            ExpandCommand = new RelayCommand(e => Expand());

        }

        private void ClearDirectoryItems()
        {
            ChildItems = new ObservableCollection<DirectoryItemViewModel>();
            if (Type != DirectoryItemTypeEnum.File)
                ChildItems.Add(null);

        }

        #endregion
    }
}
