﻿using de.mhoapps.DropToZip.Model;
using System.Windows.Input;

namespace de.mhoapps.DropToZip.ViewModel
{
    /// <summary>
    /// das ViewModel für die Einstellungen
    /// </summary>
    public class SettingsViewModel : ViewModelBase
    {
        #region Private Properties

        /// <summary>
        /// ein ModelObjekt erstellen
        /// </summary>
        private Settings _settings;
       
        #endregion

        #region Constructor

        /// <summary>
        /// default Constructor
        /// </summary>
        public SettingsViewModel()
        {
            InitializeCommands();
            ReLoad();
            SetApplicationSettings();
        }

        #endregion

        #region Public Properties

        /// <summary>
        /// der Standard ZipName aller künftigen Archive
        /// </summary>
        public TextEntryViewModel ZipName { get; set; }

        /// <summary>
        /// der Standard Pfad zum Ordner in dem alle künftigen Archive liegen
        /// </summary>
        public FolderEntryViewModel ZipPath { get; set; }


        /// <summary>
        /// der Zähler für die ZipArchive, da diese ja stets den gleichen Namen haben, 
        /// es sei denn, dieser wird vor jedem erstellen in den Einstellungen geändert
        /// </summary>
        public int ZipCounter { get; set; }


        #endregion

        #region Commands
        /// <summary>
        /// der Command zum Speichern der Einstellungen
        /// </summary>
        public ICommand SaveCommand { get; set; }

        /// <summary>
        /// der Command um die Einstellungen neu zu laden
        /// TODO: findet noch keine Verwendung, eventuell einbauen um auf Verschiebung der Settingsdatei zu reagieren
        /// </summary>
        public ICommand ReloadCommand { get; set; }

        /// <summary>
        /// der Command um den Counter zurück auf 0 zu setzen.
        /// </summary>
        public ICommand ResetCounterCommand { get; set; }


        #endregion

        #region Command Methods

        /// <summary>
        /// Methode um die Einstellungen Neu oder Erstmals zu laden
        /// </summary>
        private void ReLoad()
        {
            // dem Modelobjekt die geladenen Einstellungen zuweisen
            _settings = Settings.LoadSettings(IoC.Application.SettingsPath + @"\dtzSettings.json");

            // neue Eingabe Controls für den Namen und den Pfad erstellen und vorhandene Einstellungen zuweisen
            ZipName = new TextEntryViewModel { Label = "Zip Name", OriginalText = _settings?.DefaultZipContainerName };
            ZipPath = new FolderEntryViewModel { Label = "Zip Pfad", OriginalText = _settings?.DefaultZipContainerPath};
            ZipCounter = _settings.ZipCounter;

            //TODO: weitere Einstellungen hinzufügen, zBsp. das andocken des Fenster in einer Ecke des Bildschirm

        }

        /// <summary>
        /// Methode um die Einstellungen zu speichern
        /// </summary>
        public void Save()
        {
            // die Control ViewModels setzen beim speichern den OriginalText, 
            // diesen hier dem ModelObjekt zuweisen
            _settings.DefaultZipContainerName = ZipName.OriginalText;
            _settings.DefaultZipContainerPath = ZipPath.OriginalText;
            _settings.ZipCounter = ZipCounter;
            // ModelObjekt speichern
            Settings.SaveSettings(_settings, IoC.Application.SettingsPath + @"\dtzSettings.json");

            // die Anwendungseinstellungen setzen, damit die Properties aktualisiert werden
            // da diése Properties in einem anderen ViewModel sitzen
            SetApplicationSettings();
        }

        #endregion

        #region Helper Methods

        /// <summary>
        /// alle Commands initialisieren
        /// </summary>
        private void InitializeCommands()
        {
            SaveCommand = new RelayCommand(s => Save());
            ReloadCommand = new RelayCommand(r => ReLoad());
            ResetCounterCommand = new RelayCommand(c => ZipCounter = 0,c => ZipCounter > 0);
        }

        /// <summary>
        /// Methode um die Anwendungseinstellungen ins ApplicationViewModel zu übertragen
        /// </summary>
        private void SetApplicationSettings()
        {
            IoC.Application.ZipName = _settings?.DefaultZipContainerName;
            IoC.Application.ZipPath = _settings?.DefaultZipContainerPath;
            IoC.Application.SettingsMenuVisible = false;
        }
        #endregion
    }
}
