﻿using System.Windows.Input;

namespace de.mhoapps.DropToZip.ViewModel
{
    /// <summary>
    /// ViewModel für den FolderBrowser
    /// </summary>
    public class FolderEntryViewModel : ViewModelBase
    {
        #region Public Properties

        /// <summary>
        /// Die Bezeichnung, mit der angegeben wird, wofür dieser Wert verwendet wird
        /// </ summary>
        public string Label { get; set; }

        /// <summary>
        /// der Original Text
        /// </summary>
        public string OriginalText { get; set; }

        public bool Editing { get; set; }

        #endregion

        #region Public Commands

        public ICommand EditCommand { get; set; }

        public ICommand CancelCommand { get; set; }

        public ICommand SaveCommand { get; set; }

        public ICommand OpenFolderBrowserCommand { get; set; }
        #endregion

        #region Constructor 

        /// <summary>
        /// Default constructor
        /// </summary>
        public FolderEntryViewModel()
        {
            InitializeCommands();
            if (IsInDesignMode)
            {
                Label = "ZipName";
                OriginalText = "DropToZip";
            }
        }

        #endregion

        #region Command Methods

        /// <summary>
        /// Versetzt das Steuerelement in den Bearbeitungsmodus
        /// </ summary>
        public void Edit(object obj)
        {
            Editing = true;
        }

        /// <summary>
        /// Beendet den Bearbeitungsmodus
        /// </ summary>
        public void Cancel(object obj)
        {
            OriginalText = IoC.Application.ZipPath;
            Editing = false;
        }

        /// <summary>
        /// Überträgt den Inhalt und beendet den Bearbeitungsmodus
        /// </ summary>
        public void Save(object obj)
        {
            Editing = false;
        }

        private void OpenFolderBrowser(object obj)
        {
            IoC.UI.ShowFolderBrowser(new DialogFolderBrowserViewModel
            {
                Title = "Ordner suchen...",
                Message = "Bitte wählen Sie Ihren Zip Container Pfad",
                ButtonText = "Übernehmen"
            });
        }

        #endregion

        #region Helper Methods

        private void InitializeCommands()
        {
            EditCommand = new RelayCommand(Edit);
            CancelCommand = new RelayCommand(Cancel);
            SaveCommand = new RelayCommand(Save);
            OpenFolderBrowserCommand = new RelayCommand(OpenFolderBrowser);
        }

        #endregion
    }
}
