﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;

namespace de.mhoapps.DropToZip.ViewModel
{
    public class TextEntryViewModel : ViewModelBase
    {
        #region Public Properties

        /// <summary>
        /// Die Bezeichnung, mit der angegeben wird, wofür dieser Wert verwendet wird
        /// </ summary>
        public string Label { get; set; }

        /// <summary>
        /// der Original Text
        /// </summary>
        public string OriginalText { get; set; }

        /// <summary>
        /// der geänderte Text
        /// </summary>
        public string EditedText { get; set; }

        /// <summary>
        /// Bearbeitungsmodes einstellen
        /// </summary>
        public bool Editing { get; set; }

        #endregion

        #region Public Commands

        /// <summary>
        /// Command für den Bearbeitungsmodes zu schalten
        /// </summary>
        public ICommand EditCommand { get; set; }

        /// <summary>
        /// Command um den Bearbeitungsmodus zu beenden
        /// </summary>
        public ICommand CancelCommand { get; set; }

        /// <summary>
        ///  Command um die Properties zu speichern
        /// </summary>
        public ICommand SaveCommand { get; set; }

        #endregion

        #region Constructor 

        /// <summary>
        /// Default constructor
        /// </summary>
        public TextEntryViewModel()
        {
            InitializeCommands();
            
            if (IsInDesignMode)
            {
                Label = "ZipName";
                OriginalText = "DropToZip";
                EditedText = "ZipContainer";
            }
        }

        #endregion

        #region Command Methods

        /// <summary>
        /// Versetzt das Steuerelement in den Bearbeitungsmodus
        /// </ summary>
        public void Edit(object obj)
        {
            EditedText = OriginalText;
            Editing = true;
        }

        /// <summary>
        /// Beendet den Bearbeitungsmodus
        /// </ summary>
        public void Cancel(object obj)
        {
            Editing = false;
        }

        /// <summary>
        /// Überträgt den Inhalt und beendet den Bearbeitungsmodus
        /// </ summary>
        public void Save(object obj)
        {
            OriginalText = EditedText;
            Editing = false;
        }
        #endregion

        #region Helper Methods
        /// <summary>
        /// Commands initialisieren
        /// </summary>
        private void InitializeCommands()
        {
            EditCommand = new RelayCommand(Edit);
            CancelCommand = new RelayCommand(Cancel);
            SaveCommand = new RelayCommand(Save);
        }

        #endregion
    }
}
