﻿using Ionic.Zip;
using System.Collections.Generic;
using System.IO;
using System.Security;
using System.Threading.Tasks;

namespace de.mhoapps.DropToZip.ViewModel
{
    /// <summary>
    /// Helfer Klasse um Zip Archive zu erstellen.
    /// Nutzt das Nuget Paket DotNetZip
    /// </summary>
    public static class ZipHelper
    { 
        /// <summary>
        /// erstellt ein Zip Archiv mit allen angegebenen Datein
        /// ohne Passwort, reagiert auch auf Ordner, allerdings werden die Dateien in den Ordnern
        /// ohne Ordner ins Archiv gepackt
        /// TODO: eventuell mit FileInfo arbeiten um den Ordnernamen mit angeben zu können
        /// </summary>
        /// <param name="files">die Liste der Dateien</param>
        /// <returns></returns>
        public static async Task CreateZipFileAsync(this IEnumerable<string> files)
        {
            await Task.Run(() => 
            {
                using (ZipFile zip = new ZipFile())
                {
                    zip.CompressionLevel = Ionic.Zlib.CompressionLevel.BestCompression;
                    foreach (var file in files)
                    {
                        if (Directory.Exists(file))
                        {
                            var filesInFolder = Directory.GetFiles(file);
                            zip.AddFiles(filesInFolder,"");
                        }
                        else
                        {
                            zip.AddFile(file,"");
                        }
                    }
                    zip.Save($"{IoC.Application.ZipPath}\\{IoC.Application.ZipName}{IoC.Settings.ZipCounter}.zip");
                    IoC.Settings.ZipCounter++;
                    
                }
            });
        }

        /// <summary>
        /// erstellt ein Zip Archiv mit allen angegebenen Datein
        /// reagiert auch auf Ordner, allerdings werden die Dateien in den Ordnern
        /// ohne Ordner ins Archiv gepackt
        /// TODO: eventuell mit FileInfo arbeiten um den Ordnernamen mit angeben zu können
        /// </summary>
        /// <param name="files">die Liste aller Dateien</param>
        /// <param name="password"> das Passwort zum verschlüßeln des Containers</param>
        /// <returns></returns>
        public static async Task CreateEncryptetZipFileAsync(this IEnumerable<string> files, SecureString password)
        {
            await Task.Run(() =>
            {
                using (ZipFile zip = new ZipFile())
                {
                    zip.CompressionLevel = Ionic.Zlib.CompressionLevel.BestCompression;
                    zip.Password = password.Unsecure();
                    foreach (var file in files)
                    {
                        if (Directory.Exists(file))
                        {
                            var filesInFolder = Directory.GetFiles(file);
                            zip.AddFiles(filesInFolder, "");
                        }
                        else
                        {
                            zip.AddFile(file, "");
                        }
                    }
                    zip.Save($"{IoC.Application.ZipPath}\\{IoC.Application.ZipName}{IoC.Settings.ZipCounter}.zip");
                    IoC.Settings.ZipCounter++;
                }
            });
            }
        }
    }
