﻿using Ninject;

namespace de.mhoapps.DropToZip.ViewModel
{
    /// <summary>
    /// Inversion of Control Container dieser Anwendung
    /// </summary>
    public class IoC
    {
        #region Public Properties
        /// <summary>
        /// der Kernel für den IoC Container
        /// </summary>
        public static IKernel Kernel { get; private set; } = new StandardKernel();

        /// <summary>
        /// Eine Verknüpfung für den Zugriff auf den <see cref="IUIManager" />
        /// </ summary>
        public static IUIManager UI => IoC.Get<IUIManager>();

        /// <summary>
        /// Eine Verknüpfung für den Zugriff auf <see cref = "ApplicationViewModel" />
        /// </ summary>
        public static ApplicationViewModel Application => IoC.Get<ApplicationViewModel>();

        /// <summary>
        /// Eine Verknüpfung für den Zugriff auf <see cref = "SettingsViewModel" />
        /// </ summary>
        public static SettingsViewModel Settings => IoC.Get<SettingsViewModel>();

        #endregion

        #region Construction

        /// <summary>
        /// Richtet den IoC-Container ein, bindet alle erforderlichen Informationen und ist einsatzbereit
        /// ACHTUNG: Muss aufgerufen werden, sobald die Anwendung gestartet wird, um zu gewährleisten
        ///          das alle Services gefunden werden können (am besten in App.xaml.cs.StartUp)
        /// </ summary>
        public static void Setup()
        {
            BindViewModels();
        }

        /// <summary>
        /// Bindet alle Singelton ViewModels
        /// </summary>
        private static void BindViewModels()
        {
            Kernel.Bind<ApplicationViewModel>().ToConstant(new ApplicationViewModel());
            Kernel.Bind<SettingsViewModel>().ToConstant(new SettingsViewModel());
        }

        #endregion

        /// <summary>
        /// einen Dienst mit dem angegeben Typ vom IoC abrufen
        /// </ summary>
        /// <typeparam name = "T"> Der abzurufende Typ </ typeparam>
        /// <returns> </ returns>
        public static T Get<T>()
        {
            return Kernel.Get<T>();
        }

    }
}
